completions
===========

.. automodule:: prem.resources.completions.resource
   :members: Completions
   :undoc-members:
   :show-inheritance:

models
------
.. autoclass:: prem.resources.completions.models.ChatCompletionResponse
   :members:
   :undoc-members:

.. autoclass:: prem.resources.completions.models.ChatCompletionChunk
   :members:
   :undoc-members:

.. autoclass:: prem.resources.completions.models.Choices
   :members:
   :undoc-members:

.. autoclass:: prem.resources.completions.models.Delta
   :members:
   :undoc-members:

.. autoclass:: prem.resources.completions.models.Usage
   :members:
   :undoc-members:

.. autoclass:: prem.resources.completions.models.Choice
   :members:
   :undoc-members:

.. autoclass:: prem.resources.completions.models.Message
   :members:
   :undoc-members:
